# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-23 21:16
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('inventory', '0001_squashed_0003_auto_20150626_1807'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='category',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='inventory.Category'),
        ),
        migrations.AlterField(
            model_name='item',
            name='manufacturer',
            field=models.ForeignKey(blank=True, help_text='leave blank if unknown or same as vendor', null=True, on_delete=django.db.models.deletion.SET_NULL, to='inventory.Manufacturer'),
        ),
        migrations.AlterField(
            model_name='item',
            name='parent_item',
            field=models.ForeignKey(blank=True, help_text='example: for printer cartriges, select printer', null=True, on_delete=django.db.models.deletion.SET_NULL, to='inventory.Item'),
        ),
        migrations.AlterField(
            model_name='item',
            name='unit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='inventory.Unit'),
        ),
        migrations.AlterField(
            model_name='item',
            name='vendor',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='inventory.Vendor'),
        ),
        migrations.AlterField(
            model_name='order',
            name='ordered_by',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='order',
            name='ptao',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='inventory.PTAO'),
        ),
    ]
