{% load staticfiles %}
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="Meliza Lab">
    <meta name="author" content="CD Meliza">

    <title>{% block title %}meliza-lab{% endblock %}</title>

    <link rel="icon" type="image/png" href="{% static 'local/img/favicon.png' %}"/>
    <!-- Bootstrap core CSS -->
    <link href="{% static 'local/css/bootstrap.min.css' %}" rel="stylesheet">

    <!-- Custom styles for this template -->
    <link href="{% static 'local/css/custom.css' %}" rel="stylesheet">

    <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
      <script src="https://oss.maxcdn.com/libs/respond.js/1.3.0/respond.min.js"></script>
    <![endif]-->
  </head>

  <body>

    <!-- Fixed navbar -->
    <div class="navbar navbar-default navbar-fixed-top" role="navigation">
      <div class="container">
        <div class="navbar-header">
          <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
            <span class="sr-only">Toggle navigation</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <a class="navbar-brand" href="index.html">meliza lab internal web</a>
        </div>
        <div class="navbar-collapse collapse">
          <ul class="nav navbar-nav">
            {% block navbar %}
            <li><a href="/wiki/">Wiki</a></li>
            <li><a href="{% url 'inventory:index' %}">Inventory</a></li>
            <li><a href="{% url 'admin:index' %}">Database Admin</a></li>
            {% endblock %}
          </ul>
        </div><!--/.nav-collapse -->
      </div>
    </div>

    <div class="container">
      {% block content %}{% endblock %}
    </div> <!-- /container -->

    <!-- Bootstrap core JavaScript
    ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->
    <script src="https://code.jquery.com/jquery-1.10.2.min.js"></script>
    <script src="{% static 'local/js/bootstrap.min.js' %}"></script>
  </body>
</html>
